data_conf = {
    "bed_temp": {"reactor_attr": "T", "units": "C", "tag": "TIC02"},
    "pressure": {"reactor_attr": "P", "units": "bar", "tag": "PIC01"},
    "n2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC01"},
    "co2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC02"},
    "h2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC03"},
}