data_conf = {
    "bed_temp": {"reactor_attr": "T", "units": "C", "tag": "TIC02"},
    "pressure": {"reactor_attr": "P", "units": "bar", "tag": "PIC01"},
    "n2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC01"},
    "co2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC02"},
    "h2_mfc": {"reactor_attr": "Ft0", "units": "smLmin", "tag": "FIC03"},
}
components = {
    "n2": {"mol_weight": 28, "type": "inert"},
    "co2": {"mol_weight": 44, "c_atoms": 1, "o_atoms": 2, "type": "reactant"},
    "h2": {"mol_weight": 2, "type": "reactant", "h_atoms": 2},
    "co": {
        "mol_weight": 28,
        "c_atoms": 1,
        "o_atoms": 1,
        "type": "product",
    },
    "ch4": {
        "mol_weight": 16,
        "c_atoms": 1,
        "h_atoms": 4,
        "type": "product",
    },
    "c2h4": {
        "mol_weight": 28,
        "c_atoms": 2,
        "h_atoms": 4,
        "type": "product",
    },
    "c2h6": {
        "mol_weight": 30,
        "c_atoms": 2,
        "h_atoms": 6,
        "type": "product",
    },
    "c3h6": {
        "mol_weight": 42,
        "c_atoms": 3,
        "h_atoms": 6,
        "type": "product",
    },
    "c3h8": {
        "mol_weight": 44,
        "c_atoms": 3,
        "h_atoms": 8,
        "type": "product",
    },
    "c4h8": {
        "mol_weight": 56,
        "c_atoms": 4,
        "h_atoms": 8,
        "type": "product",
    },
    "c4h10": {
        "mol_weight": 58,
        "c_atoms": 4,
        "h_atoms": 10,
        "type": "product",
    },
    "c5h10": {
        "mol_weight": 70,
        "c_atoms": 5,
        "h_atoms": 10,
        "color": "green",
    },
    "c5h12": {
        "mol_weight": 72,
        "c_atoms": 5,
        "h_atoms": 12,
        "type": "product",
    },
    "h2o": {"mol_weight": 18, "type": "product", "h_atoms": 2, "o_atoms": 1},
}
